@@ -17,7 +17,7 @@ rewarding_analytics_data_bp = Blueprint('rewarding_analytics_data_bp', __name__,
                                  static_folder='static',
                                  url_prefix='/analytics/rewarding')
 
-logger = logging.getLogger('query')
+logger = logging.getLogger('analytics')
 
 query_rewarding_data_api = Api(rewarding_analytics_data_bp)
 
